PumpError

Enum PumpError 

pub enum PumpError {
Show 31 variants NotAuthorized = 6_000, AlreadyInitialized = 6_001, TooMuchSolRequired = 6_002, TooLittleSolReceived = 6_003, MintDoesNotMatchBondingCurve = 6_004, BondingCurveComplete = 6_005, BondingCurveNotComplete = 6_006, NotInitialized = 6_007, WithdrawTooFrequent = 6_008, NewSizeShouldBeGreaterThanCurrentSize = 6_009, AccountTypeNotSupported = 6_010, InitialRealTokenReservesShouldBeLessThanTokenTotalSupply = 6_011, InitialVirtualTokenReservesShouldBeGreaterThanInitialRealTokenReserves = 6_012, FeeBasisPointsGreaterThanMaximum = 6_013, AllZerosWithdrawAuthority = 6_014, PoolMigrationFeeShouldBeLessThanFinalRealSolReserves = 6_015, PoolMigrationFeeShouldBeGreaterThanCreatorFeePlusMaxMigrateFees = 6_016, DisabledWithdraw = 6_017, DisabledMigrate = 6_018, InvalidCreator = 6_019, BuyZeroAmount = 6_020, NotEnoughTokensToBuy = 6_021, SellZeroAmount = 6_022, NotEnoughTokensToSell = 6_023, Overflow = 6_024, Truncation = 6_025, DivisionByZero = 6_026, NotEnoughRemainingAccounts = 6_027, AllFeeRecipientsShouldBeNonZero = 6_028, UnsortedNotUniqueFeeRecipients = 6_029, CreatorShouldNotBeZero = 6_030,
}

Variants



NotAuthorized = 6_000

6000 - The given account is not authorized to execute this instruction.



AlreadyInitialized = 6_001

6001 - The program is already initialized.



TooMuchSolRequired = 6_002

6002 - slippage: Too much SOL required to buy the given amount of tokens.



TooLittleSolReceived = 6_003

6003 - slippage: Too little SOL received to sell the given amount of tokens.



MintDoesNotMatchBondingCurve = 6_004

6004 - The mint does not match the bonding curve.



BondingCurveComplete = 6_005

6005 - The bonding curve has completed and liquidity migrated to raydium.



BondingCurveNotComplete = 6_006

6006 - The bonding curve has not completed.



NotInitialized = 6_007

6007 - The program is not initialized.



WithdrawTooFrequent = 6_008

6008 - Withdraw too frequent



NewSizeShouldBeGreaterThanCurrentSize = 6_009

6009 - new_size should be > current_size



AccountTypeNotSupported = 6_010

6010 - Account type not supported



InitialRealTokenReservesShouldBeLessThanTokenTotalSupply = 6_011

6011 - initial_real_token_reserves should be less than token_total_supply



InitialVirtualTokenReservesShouldBeGreaterThanInitialRealTokenReserves = 6_012

6012 - initial_virtual_token_reserves should be greater than initial_real_token_reserves



FeeBasisPointsGreaterThanMaximum = 6_013

6013 - fee_basis_points greater than maximum



AllZerosWithdrawAuthority = 6_014

6014 - Withdraw authority cannot be set to System Program ID



PoolMigrationFeeShouldBeLessThanFinalRealSolReserves = 6_015

6015 - pool_migration_fee should be less than final_real_sol_reserves



PoolMigrationFeeShouldBeGreaterThanCreatorFeePlusMaxMigrateFees = 6_016

6016 - pool_migration_fee should be greater than creator_fee + MAX_MIGRATE_FEES



DisabledWithdraw = 6_017

6017 - Migrate instruction is disabled



DisabledMigrate = 6_018

6018 - Migrate instruction is disabled



InvalidCreator = 6_019

6019 - Invalid creator pubkey



BuyZeroAmount = 6_020

6020 - Buy zero amount



NotEnoughTokensToBuy = 6_021

6021 - Not enough tokens to buy



SellZeroAmount = 6_022

6022 - Sell zero amount



NotEnoughTokensToSell = 6_023

6023 - Not enough tokens to sell



Overflow = 6_024

6024 - Overflow



Truncation = 6_025

6025 - Truncation



DivisionByZero = 6_026

6026 - Division by zero



NotEnoughRemainingAccounts = 6_027

6027 - Not enough remaining accounts



AllFeeRecipientsShouldBeNonZero = 6_028

6028 - All fee recipients should be non-zero



UnsortedNotUniqueFeeRecipients = 6_029

6029 - Unsorted or not unique fee recipients



CreatorShouldNotBeZero = 6_030

6030 - Creator should not be zero